@@ -30,13 +30,21 @@
 
 /**
  * Named constants for return values.  The following
- * invariants hold: "NO == 0" (to allow "if (NO)")
- * "OK != SYSERR", "OK != NO", "NO != SYSERR"
- * and finally "YES != NO".
+ * invariants hold: "GNUNET_NO == 0" (to allow "if (GNUNET_NO)")
+ * "GNUNET_OK != GNUNET_SYSERR", "GNUNET_OK != GNUNET_NO", "GNUNET_NO != GNUNET_SYSERR"
+ * and finally "GNUNET_YES != GNUNET_NO".
  */
-#define OK      1
-#define SYSERR -1
-#define YES     1
-#define NO      0
+#define GNUNET_OK      1
+#define GNUNET_SYSERR -1
+#define GNUNET_YES     1
+#define GNUNET_NO      0
 
-#endif /*GNUNET_UTIL_COMMON_H_*/
+#if __STDC_VERSION__ < 199901L
+# if __GNUC__ >= 2
+#  define __func__ __FUNCTION__
+# else
+#  define __func__ "<unknown>"
+# endif
+#endif
+
+#endif /*GNUNET_UTIL_COMMON_H_ */
