@@ -28,20 +28,18 @@
 #ifndef GNUNET_SETUP_GCONF_H
 #define GNUNET_SETUP_GCONF_H
 
-int gconf_mainsetup_gtk(int argc,
-			const char ** argv,
-			struct PluginHandle * self,
-			struct GE_Context * ectx,
-			struct GC_Configuration * cfg,
-			struct GNS_Context * gns,
-			const char * filename,
-			int is_daemon);
+int gconf_mainsetup_gtk (int argc,
+                         const char **argv,
+                         struct GNUNET_PluginHandle *self,
+                         struct GNUNET_GE_Context *ectx,
+                         struct GNUNET_GC_Configuration *cfg,
+                         struct GNUNET_GNS_Context *gns,
+                         const char *filename, int is_daemon);
 
-int gconf_main_post_init(struct PluginHandle * lib,
-			 struct GE_Context * e,
-			 struct GC_Configuration * c,
-			 struct GNS_Context * gns,
-			 const char * filename,
-			 int is_daemon);
+int gconf_main_post_init (struct GNUNET_PluginHandle *lib,
+                          struct GNUNET_GE_Context *e,
+                          struct GNUNET_GC_Configuration *c,
+                          struct GNUNET_GNS_Context *gns,
+                          const char *filename, int is_daemon);
 
 #endif
