@@ -25,24 +25,24 @@
 #include <gtk/gtktext.h>
 #include <glade/glade.h>
 
-#define mainXML getMainXML()
+#define mainXML GNUNET_GTK_get_main_glade_XML()
 
-GladeXML * getMainXML(void);
+GladeXML *GNUNET_GTK_get_main_glade_XML (void);
 
-void destroyMainXML(void);
+void destroyMainXML (void);
 
-void setLibrary(struct PluginHandle * lib);
+void setLibrary (struct GNUNET_PluginHandle *lib);
 
-GtkWidget * get_xml(const char * dialog_name);
+GtkWidget *get_xml (const char *dialog_name);
 
-GladeXML * load_xml(const char * dialog_name);
+GladeXML *load_xml (const char *dialog_name);
 
 /**
  * Helper function to just show a simple dialog
  * that requires no initialization.
  */
-void showDialog(const char * name);
+void showDialog (const char *name);
 
-GtkWidget * lookup_widget(const char * name);
+GtkWidget *lookup_widget (const char *name);
 
 #endif
