@@ -27,9 +27,15 @@
 #ifndef WIZARD_UTIL_H_
 #define WIZARD_UTIL_H_
 
-int wiz_is_nic_default(struct GC_Configuration *cfg, const char *name, int suggestion);
-int wiz_autostartService(int doAutoStart, char *username, char *groupname);
-int wiz_createGroupUser(char *group_name, char *user_name);
+#define GNUNET_SERVICE_TYPE_GNUNETD 1
+#define GNUNET_SERVICE_TYPE_AUTOSHARE 2
+
+int GNUNET_GNS_wiz_is_nic_default (struct GNUNET_GC_Configuration *cfg,
+                                   const char *name, int suggestion);
+int GNUNET_GNS_wiz_autostart_service (struct GNUNET_GE_Context *ectx,
+                                      int serviceType, int doAutoStart,
+                                      char *username, char *groupname);
+int GNUNET_GNS_wiz_create_group_user (char *group_name, char *user_name);
 
 
-#endif /*WIZARD_UTIL_H_*/
+#endif /*WIZARD_UTIL_H_ */
