@@ -34,13 +34,13 @@
  * Get the IP address for the local machine.
  * @return NULL on error
  */
-char * gaim_upnp_get_internal_ip(struct GC_Configuration * cfg,
-				 struct GE_Context * ectx) {
-  IPaddr address;
+char *
+GNUNET_upnp_get_internal_ip (struct GNUNET_GC_Configuration *cfg,
+                             struct GNUNET_GE_Context *ectx)
+{
+  struct in_addr address;
 
-  return network_get_local_ip(cfg,
-			      ectx,
-			      &address);
+  return GNUNET_get_local_ip (cfg, ectx, &address);
 }
 
 
