@@ -28,11 +28,12 @@
 #define NETWORK_H
 
 
-typedef struct SocketHandle {
+typedef struct GNUNET_SocketHandle
+{
 
-  struct LoadMonitor * mon;
+  struct GNUNET_LoadMonitor *mon;
 
-  struct GE_Context * ectx;
+  struct GNUNET_GE_Context *ectx;
 
   int handle;
 
